<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Awards extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-awards-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Awards', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Awards Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Hello World', 'kanun-core')],
					],
				'fields' => 
					[						

						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_text' =>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],
						
						'block_image' =>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'kanun-core' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_subtitle' =>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Subtitle', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>


	<div class="award-main-wrapper m-0 p-0">
		<?php foreach($settings['repeat'] as $item):?>	
		<div class="award-wrapper wow fadeInUp" data-wow-delay=".3s">
			<div class="award-item">
				<div class="content">
					<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
				</div>
				<div class="text">
					<?php echo wp_kses($item['block_text'], $allowed_tags);?>
				</div>
			</div>
			<div class="year-item">
				<div class="year-image">
					<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="">		
				</div>
				<div class="cont">
					<h3><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></h3>
				</div>
			</div>
		</div>
		<?php endforeach; ?>
	</div>

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Awards());