<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Banner extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-banner-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Banner', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'banner',
			[
				'label' => esc_html__( 'Banner', 'kanun-core' ),
			]
		);	

		$this->add_control(
            'style',
            [
                'label'   => esc_html__( 'Select Style', 'kanun-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style1',
                'options' => array(
                    'style1'   => esc_html__( 'Style One', 'kanun-core' ),
                    'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
                ),
            ]
        );

		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__('Background image', 'kanun-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition'	=> ['style' => ['style1','style2']],
			]
		);

		$this->add_control(
			'video_link',
			[
			  'label' => __( 'Video Url', 'kanun-core' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
			  'show_external' => true,
			  'default' => [
				'url' => 'https://www.youtube.com/watch?v=Cn4G2lZ_g2I',
				'is_external' => true,
				'nofollow' => true,
			  ],
			  'condition'	=> ['style' => ['style1']],
			
		   ]
		);

		$this->add_control(
			'play_title',
			[
				'label'       => __( 'Play Button Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
				'condition'	=> ['style' => ['style1']],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
				'condition'	=> ['style' => ['style1','style2']],
			]
		);

		$this->add_control(
			'title2',
			[
				'label'       => __( 'Title 2', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
				'condition'	=> ['style' => ['style2']],
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your sub-title', 'kanun-core' ),
				'condition'	=> ['style' => ['style1','style2']],
			]
		);

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your button text', 'kanun-core' ),
				'default' => esc_html__('Read More', 'kanun-core'),
				'condition'	=> ['style' => ['style1','style2']],
			]
		);

		$this->add_control(
			'button_link',
			[
			  'label' => __( 'Button Url', 'kanun-core' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			  'condition'	=> ['style' => ['style1','style2']],
			
		   ]
		);

		$this->add_control(
			'number_stop',
			[
			'label' => __( 'Counter Stop', 'kanun-core' ),
			'type' => Controls_Manager::TEXT,
			'dynamic' => [
			'active' => true,
			],
			'placeholder' => __( 'Enter Counter Stop', 'kanun-core' ),
			'condition'	=> ['style' => ['style1']],
			]
		);	
	
		$this->add_control(
			'number_sign',
			[
			'label' => __( 'Counter Sign', 'kanun-core' ),
			'type' => Controls_Manager::TEXT,
			'dynamic' => [
			'active' => true,
			],
			'placeholder' => __( 'Enter Counter Sing', 'kanun-core' ),
			'condition'	=> ['style' => ['style1']],
			]
		);

		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1','style2']],
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				  'condition'	=> ['style' => ['style1','style2']],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1','style2']],
			]
		);

		$this->add_control(
			'image2',
				[
				  'label' => __( 'Image 2', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				  'condition'	=> ['style' => ['style2']],
				]
		);	
		
		$this->add_control(
			'alt_text2',
			[
				'label'       => __( 'Alt text 2', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style2']],
			]
		);


		$this->end_controls_section();


	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

	
	<?php  if ( 'style1' === $settings['style'] ) : ?>
      <!-- Hero Section Start -->
	  
		<section class="hero-section hero-1 fix bg-cover" style="background-image: url('<?php echo wp_get_attachment_url($settings['bg_image']['id']);?>');">
			<?php if($settings['play_title']): ?>
            <div class="hero-video">
                <div class="watch-btn">
                    <a href="<?php echo esc_url($settings['video_link']['url']);?>" data-animation="slideInRight" data-duration="2s" data-delay=".7s" class="video-btn ripple video-popup">
                    <i class="fa-duotone fa-play"></i>
                </a>
                </div>
                <h6>
					<?php echo $settings['play_title'];?>
               </h6>
            </div>
			<?php endif; ?>
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6">
                        <div class="hero-content">
                            <h1 class="wow fadeInUp" data-wow-delay=".3s">
								<?php echo $settings['title'];?>
                            </h1>
                            <p class="wow fadeInUp" data-wow-delay=".5s">
								<?php echo $settings['subtitle'];?>
                            </p>
                            <div class="hero-button">
								<?php if($settings['button']): ?>
                                <a href="<?php echo esc_url($settings['button_link']['url']);?>" class="theme-btn wow fadeInUp" data-wow-delay=".3s">
									<?php echo $settings['button'];?>
                                    <i class="fa-solid fa-arrow-right-long"></i>
                                </a>
								<?php endif; ?>
                                <div class="counter-content wow fadeInUp" data-wow-delay=".5s">
                                    <h2><span class="count"><?php echo esc_attr($settings['number_stop']);?></span><?php echo esc_attr($settings['number_sign']);?></h2>
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="hero-image wow img-custom-anim-left">
						<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
							<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
						<?php endif;?>
                        </div>
                    </div>
                </div>
            </div>
        </section>

		<?php  elseif ( 'style2' === $settings['style'] ) : ?>

		<section class="hero-section hero-2 fix bg-cover" style="background-image: url('<?php echo wp_get_attachment_url($settings['bg_image']['id']);?>');">
            <div class="hero-image">
			<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
				<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
			<?php endif;?>
            </div>
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-9">
                        <div class="hero-content">
                            <span><?php echo $settings['subtitle'];?></span>
                            <h1 class="wow fadeInUp" data-wow-delay=".3s">
							<?php echo $settings['title'];?>
								<?php  if ( !empty(esc_url($settings['image2']['id']) )) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
								<?php endif;?>
							<?php echo $settings['title2'];?>
							</h1>
                            <p class="wow fadeInUp" data-wow-delay=".5s">
								<?php echo $settings['text'];?>
                            </p>
							<?php if($settings['button']): ?>
                            <div class="hero-button wow fadeInUp" data-wow-delay=".7s">
                                <a href="<?php echo esc_url($settings['button_link']['url']);?>" class="theme-btn">
									<?php echo $settings['button'];?>
                                    <i class="fa-solid fa-arrow-right-long"></i>
                                </a>
                            </div>
							<?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>

		<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Banner());