<?php
/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */

namespace Elementor;

class Blog_Post extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'kanun-blog-post-widget';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Blog Post', 'kanun-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-post';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['kanun_widgets'];
    }

    /**
     * Register Elementor widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'settings_section',
            [
                'label' => esc_html__('General Settings', 'kanun-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'   => esc_html__( 'Select Style', 'kanun-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style1',
                'options' => array(
                    'style1'   => esc_html__( 'Style One', 'kanun-core' ),
                    'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
                    'style3'   => esc_html__( 'Style Three', 'kanun-core' ),
                ),
            ]
        );
        
        $this->add_control('blog_grid', [
            'label' => esc_html__('Blog Grid', 'kanun-core'),
            'type' => Controls_Manager::SELECT,
            'options' => array(
                'col-lg-2' => esc_html__('col-lg-2', 'kanun-core'),
                'col-lg-3' => esc_html__('col-lg-3', 'kanun-core'),
                'col-lg-4' => esc_html__('col-lg-4', 'kanun-core'),
                'col-lg-6' => esc_html__('col-lg-6', 'kanun-core'),
                'col-lg-12' => esc_html__('col-lg-12', 'kanun-core'),
            ),
            'default' => 'col-lg-4',
            'description' => esc_html__('Select Blog Grid', 'kanun-core')
        ]);   
        
        $this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your button text', 'kanun-core' ),
				'default' => esc_html__('Read More', 'kanun-core'),
			]
		);	

        $this->add_control(
            'word_limit',
            [
                'label' => esc_html__('Word Limit', 'kanun-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => 20,
                'description' => esc_html__('Set the number of words to display from the post content.', 'kanun-core'),
            ]
        );

        $this->add_control(
            'more_text',
            [
                'label' => esc_html__('More Text', 'kanun-core'),
                'type' => Controls_Manager::TEXT,
                'default' => '...',
                'description' => esc_html__('Set the text to append after the trimmed words, e.g., "Read More". Leave blank for no text.', 'kanun-core'),
            ]
        );
   
        $this->add_control('total', [
            'label' => esc_html__('Total Posts', 'kanun-core'),
            'type' => Controls_Manager::TEXT,
            'default' => '-1',
            'description' => esc_html__('enter how many post you want in masonry , enter -1 for unlimited post.')
        ]);
        $this->add_control('offset', [
            'label' => esc_html__('Offset Posts', 'kanun-core'),
            'type' => Controls_Manager::TEXT,
            'default' => '0',
            'description' => esc_html__('enter how many post you want in masonry , enter -1 for unlimited post.')
        ]);
        $this->add_control('category', [
            'label' => esc_html__('Category', 'kanun-core'),
            'type' => Controls_Manager::SELECT2,
            'multiple' => true,
            'options' => kanun_core()->get_terms_names('category', 'id'),
            'description' => esc_html__('Select category as you want, leave it blank for all categories', 'kanun-core'),
        ]);        

        $this->add_control('order', [
            'label' => esc_html__('Order', 'kanun-core'),
            'type' => Controls_Manager::SELECT,
            'options' => array(
                'ASC' => esc_html__('Ascending', 'kanun-core'),
                'DESC' => esc_html__('Descending', 'kanun-core'),
            ),
            'default' => 'DESC',
            'description' => esc_html__('select order', 'kanun-core')
        ]);
        $this->add_control('orderby', [
            'label' => esc_html__('OrderBy', 'kanun-core'),
            'type' => Controls_Manager::SELECT,
            'options' => array(
                'ID' => esc_html__('ID', 'kanun-core'),
                'title' => esc_html__('Title', 'kanun-core'),
                'date' => esc_html__('Date', 'kanun-core'),
                'rand' => esc_html__('Random', 'kanun-core'),
                'comment_count' => esc_html__('Most Comments', 'kanun-core'),
            ),
            'default' => 'ID',
            'description' => esc_html__('select order', 'kanun-core')
        ]);      
        
           $this->add_control(
            'image_thumb_display',
            [
                'label' => esc_html__('Image Display', 'kanun-core'),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__('show/hide description', 'kanun-core'),
            ]
        );
        
        $this->add_control(
            'thumb_date',
            [
                'label' => esc_html__('Thumb Date Show/Hide', 'kanun-core'),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__('show/hide description', 'kanun-core'),
            ]
        );
      
        $this->add_control(
            'pagination',
            [
                'label' => esc_html__('Pagination', 'kanun-core'),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__('you can set yes to show pagination.', 'kanun-core'),
                'default' => 'no',
            ]
        );
        
          $this->add_control(
            'category_display',
            [
                'label' => esc_html__('Category Display', 'kanun-core'),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__('Show  Or Hide Category.', 'kanun-core'),
            ]
        );

          $this->add_control(
            'tag_display',
            [
                'label' => esc_html__('Tags Display', 'kanun-core'),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__('Show  Or Hide Tags.', 'kanun-core'),
            ]
        );
        
        $this->add_control(
            'pagination_alignment',
            [
                'label' => esc_html__('Pagination Alignment', 'kanun-core'),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'start' => esc_html__('Left Align', 'kanun-core'),
                    'center' => esc_html__('Center Align', 'kanun-core'),
                    'end' => esc_html__('Right Align', 'kanun-core'),
                ),
                'description' => esc_html__('you can set pagination alignment.', 'kanun-core'),
                'default' => 'start',
                'condition' => array('pagination' => 'yes'),
            ]
        );
        $this->end_controls_section();


    }

    /**
     * Render Elementor widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $rand_numb = rand(333, 999999999);
        //query settings
        $total_posts = $settings['total'];
        $category = $settings['category'];
        $order = $settings['order'];
        $orderby = $settings['orderby'];
        $offset = $settings['offset'];
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

        //other settings
        $pagination = $settings['pagination'] ? false : true;
        $pagination_alignment = $settings['pagination_alignment'];

        //setup query       

        $args = array(
            'post_type' => 'post',
            'posts_per_page' => $total_posts,
            'order' => $order,
            'orderby' => $orderby,
            'paged' => $paged, // Use paged instead of offset
            'post_status' => 'publish',
            'ignore_sticky_posts' => 1,
        );
        
        if (!empty($category)) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'category',
                    'field' => 'term_id',
                    'terms' => $category
                )
            );
        }
        
        $post_data = new \WP_Query($args);
        

        ?>

        
        <?php  if ( 'style1' === $settings['style'] ) : ?>

        <?php while ($post_data->have_posts()):$post_data->the_post(); 
            $img_id = get_post_thumbnail_id(get_the_ID()) ? get_post_thumbnail_id(get_the_ID()) : false;
            $img_url_val = $img_id ? wp_get_attachment_image_src($img_id, 'kanun_grid_blog_12', false) : '';
            $img_url = is_array($img_url_val) && !empty($img_url_val) ? $img_url_val[0] : '';
            $img_alt = get_post_meta($img_id, '_wp_attachment_image_alt', true);

            $comments_count = get_comments_number(get_the_ID());
            $comment_text = ($comments_count > 1) ? 'Comments (' . $comments_count . ')' : 'Comment (' . $comments_count . ')';
        ?> 
        <div class="news-card-items img-custom-anim-right wow" data-wow-delay=".3s">
            <?php if(!empty($settings['image_thumb_display'])) : ?>
            <div class="news-image">
                <img src="<?php echo esc_url($img_url); ?>" alt="<?php echo esc_attr($img_alt); ?>">
            </div>
            <?php endif; ?>
            <div class="news-content">
                <ul class="post-meta">
                    <?php if(!empty($settings['thumb_date'])) : ?>
                    <li><?php echo get_the_date('F j, Y');?></li>
                    <?php endif; ?>
                    <?php if(!empty($settings['category_display'])) : ?>
                    <li>
                    <?php
                        $post_category = get_the_category();
                        if ($post_category) {
                            $first_category = reset($post_category);
                            echo '<a href="' . get_tag_link($first_category->term_id) . '">' . $first_category->name . '</a>';
                        } else {
                            echo "No category found";
                        }
                    ?>  
                    </li>
                    <?php endif; ?>
                </ul>
                <h4>
                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                </h4>
                <a href="<?php the_permalink(); ?>" class="link-btns">
                <?php echo $settings['button'];?> <i class="fa-solid fa-arrow-right"></i>
                </a>
            </div>
        </div>
        <?php
            endwhile;
            wp_reset_query();
        ?>
        <?php if (!$pagination) { ?>
            <div class="col-lg-12">
                <div class="blog-pagination text-<?php echo esc_attr($pagination_alignment) ?> margin-top-20">
                    
                        <?php kanun()->post_pagination($post_data); ?>

                </div>
            </div>
        <?php } ?>


        <?php  elseif ( 'style2' === $settings['style'] ) : ?>

            <div class="row">
                <?php while ($post_data->have_posts()):$post_data->the_post(); 
                    $img_id = get_post_thumbnail_id(get_the_ID()) ? get_post_thumbnail_id(get_the_ID()) : false;
                    $img_url_val = $img_id ? wp_get_attachment_image_src($img_id, 'kanun_grid_blog_12', false) : '';
                    $img_url = is_array($img_url_val) && !empty($img_url_val) ? $img_url_val[0] : '';
                    $img_alt = get_post_meta($img_id, '_wp_attachment_image_alt', true);

                    $comments_count = get_comments_number(get_the_ID());
                    $comment_text = ($comments_count > 1) ? 'Comments (' . $comments_count . ')' : 'Comment (' . $comments_count . ')';
                ?> 
                <div class="<?php echo esc_attr($settings['blog_grid']); ?> col-md-6 wow fadeInUp" data-wow-delay=".3s">
                    <div class="news-card-items-2">
                        <?php if(!empty($settings['image_thumb_display'])) : ?>
                        <div class="news-image">
                            <img src="<?php echo esc_url($img_url); ?>" alt="<?php echo esc_attr($img_alt); ?>">
                        </div>
                        <?php endif; ?>
                        <div class="news-content">
                        <ul class="post-meta mb-3">
                            <?php if(!empty($settings['thumb_date'])) : ?>
                            <li><?php echo get_the_date('F j, Y');?></li>
                            <?php endif; ?>
                            <?php if(!empty($settings['category_display'])) : ?>
                            <li>
                            <?php
                                $post_category = get_the_category();
                                if ($post_category) {
                                    $first_category = reset($post_category);
                                    echo '<a href="' . get_tag_link($first_category->term_id) . '">' . $first_category->name . '</a>';
                                } else {
                                    echo "No category found";
                                }
                            ?>  
                            </li>
                            <?php endif; ?>
                        </ul>
                            <h4>
                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                            </h4>
                            <a href="<?php the_permalink(); ?>" class="link-btns">
                                <?php echo $settings['button'];?> <i class="fa-solid fa-arrow-right"></i>
                            </a>
                        </div>
                    </div>
                </div>
                <?php
                    endwhile;
                    wp_reset_query();
                ?>
                <?php if (!$pagination) { ?>
                    <div class="col-lg-12">
                        <div class="blog-pagination text-<?php echo esc_attr($pagination_alignment) ?> margin-top-20">
                            
                                <?php kanun()->post_pagination($post_data); ?>

                        </div>
                    </div>
                <?php } ?>
            </div>

        <?php  elseif ( 'style3' === $settings['style'] ) : ?>

            <div class="row">
                <?php while ($post_data->have_posts()):$post_data->the_post(); 
                    $img_id = get_post_thumbnail_id(get_the_ID()) ? get_post_thumbnail_id(get_the_ID()) : false;
                    $img_url_val = $img_id ? wp_get_attachment_image_src($img_id, 'kanun_grid_blog_12', false) : '';
                    $img_url = is_array($img_url_val) && !empty($img_url_val) ? $img_url_val[0] : '';
                    $img_alt = get_post_meta($img_id, '_wp_attachment_image_alt', true);

                    $comments_count = get_comments_number(get_the_ID());
                    $comment_text = ($comments_count > 1) ? 'Comments (' . $comments_count . ')' : 'Comment (' . $comments_count . ')';
                ?> 
                <div class="col-lg-6">
                    <div class="news-card-items-3 img-custom-anim-left wow" data-wow-delay=".3s">
                        <?php if(!empty($settings['image_thumb_display'])) : ?>
                        <div class="news-image">
                            <img src="<?php echo esc_url($img_url); ?>" alt="<?php echo esc_attr($img_alt); ?>">
                        </div>
                        <?php endif; ?>
                        <div class="news-content">
                            <h3>
                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                            </h3>
                            <ul class="news-post">
                                <li>
                                    <i class="fa-regular fa-user"></i>
                                    <?php the_author(); ?>
                                </li>
                                <?php if(!empty($settings['thumb_date'])) : ?>
                                <li>
                                    <i class="fa-solid fa-calendar-days"></i>
                                    <?php echo get_the_date('F j, Y');?>
                                </li>
                                <?php endif; ?>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php
                    endwhile;
                    wp_reset_query();
                ?>
                <?php if (!$pagination) { ?>
                    <div class="col-lg-12">
                        <div class="blog-pagination text-<?php echo esc_attr($pagination_alignment) ?> margin-top-20">
                            
                                <?php kanun()->post_pagination($post_data); ?>

                        </div>
                    </div>
                <?php } ?>
            </div>

        <?php endif ;?>	

        <?php
    }
}

Plugin::instance()->widgets_manager->register_widget_type(new Blog_Post());