<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Consultation_Cta extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-consultation-cta-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Consultation Cta', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'consultation_cta',
			[
				'label' => esc_html__( 'Consultation Cta', 'kanun-core' ),
			]
		);	
		
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your sub title', 'kanun-core' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
			]
		);


		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
			]
		);

		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__('Background image', 'kanun-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);

		$this->add_control(
			'contact_form_7',
			[
				'label'       => __( 'Contact Form 7 Url', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Contact Form 7 Url', 'kanun-core' ),
				'default'     => __( '', 'kanun-core' ),
			]
		);

		$this->end_controls_section();
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

	<section class="cta-request-section section-padding fix bg-cover" style="background-image: url('<?php echo wp_get_attachment_url($settings['bg_image']['id']);?>');">
		<div class="container">
			<div class="row">
				<div class="col-xl-7">
					<div class="cta-request-content">
						<div class="section-title">
							<span class="sub-title text-white wow fadeInUp">
								<?php echo esc_attr($settings['subtitle']);?>
							</span>
							<h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
								<?php echo esc_attr($settings['title']);?>
							</h2>
						</div>
						<p class="text-white wow fadeInUp" data-wow-delay=".5s">
							<?php echo esc_attr($settings['text']);?>
						</p>
						<div class="search-widget wow fadeInUp" data-wow-delay=".7s">
							<?php echo do_shortcode( $settings['contact_form_7'] );?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Consultation_Cta());