<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Contact_Form extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-contact-form-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Form', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'contact_form',
			[
				'label' => esc_html__( 'Contact Form', 'kanun-core' ),
			]
		);		
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
					'style3'   => esc_html__( 'Style Three', 'kanun-core' ),
				),
			]
		);
		
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your sub title', 'kanun-core' ),
			]
		);

		$this->add_control(
				'title',
				[
					'label'       => __( 'Title', 'kanun-core' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter your title', 'kanun-core' ),
				]
			);

		$this->add_control(
			'contact_form_7',
			[
				'label'       => __( 'Contact Form 7 Url', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Contact Form 7 Url', 'kanun-core' ),
				'default'     => __( '', 'kanun-core' ),
			]
		);

		$this->end_controls_section();
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>


<?php  if ( 'style1' === $settings['style'] ) : ?>	

	<div class="appointment-wrapper">
		<div class="contact-content">
			<span class="wow fadeInUp" data-wow-delay=".3s"><?php echo esc_attr($settings['subtitle']);?></span>
			<h3 class="wow fadeInUp" data-wow-delay=".5s">
				<?php echo esc_attr($settings['title']);?>
			</h3>
			<?php echo do_shortcode( $settings['contact_form_7'] );?>
		</div>
	</div>

<?php  elseif ( 'style2' === $settings['style'] ) : ?>
   
<div class="service-details-wrapper">
    <div class="service-details-post">
        <div class="details-content mt-0">
            <div class="contact-form-items mt-0 pt-0 border-0">
				<?php echo do_shortcode( $settings['contact_form_7'] );?>
            </div>
        </div>
    </div>
</div>

<?php  elseif ( 'style3' === $settings['style'] ) : ?>

	<div class="contact-form-items m-0 p-0">
		<div class="row justify-content-center m-0 p-0">
			<div class="col-xl-8">
				<?php echo do_shortcode( $settings['contact_form_7'] );?>
			</div>
		</div>
	</div>

<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Contact_Form());