<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Pricing extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-pricing-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pricing Widgets', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'pricing',
			[
				'label' => esc_html__( 'Pricing', 'kanun-core' ),
			]
		);	

			$this->add_control(
				'title',
				[
					'label'       => __( 'Title', 'kanun-core' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter your title', 'kanun-core' ),
				]
			);
	
			$this->add_control(
				'text',
				[
					'label'       => __( 'Description Text', 'kanun-core' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				]
			);

			$this->add_control(
				'subtitle',
				[
					'label'       => __( 'Sub Title', 'kanun-core' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter your sub title', 'kanun-core' ),
				]
			);

			$this->add_control(
				'text2',
				[
					'label'       => __( 'List Text', 'kanun-core' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				]
			);

			$this->add_control(
				'button',
				[
					'label'       => __( 'Button', 'kanun-core' ),
					'type'        => Controls_Manager::TEXT,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'Enter your button text', 'kanun-core' ),
					'default' => esc_html__('Read More', 'kanun-core'),
				]
			);	

	
			$this->add_control(
				'button_link',
				[
				  'label' => __( 'Button Url', 'kanun-core' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
				  'show_external' => true,
				  'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				  ],
				
			   ]
			);

			$this->add_control(
				'active_class',
				[
					'label'   => esc_html__( 'Active Options', 'kanun-core' ),
					'type' => Controls_Manager::SELECT,
					'options' => array(
					'style-1'   => esc_html__( 'Style 1', 'kanun-core' ),
					'style-2'   => esc_html__( 'Style 2', 'kanun-core' ),
					'style-3'   => esc_html__( 'Style 3', 'kanun-core' ),
					),
					'default' => 'style-1',
				]
			);

		$this->end_controls_section();


	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

		<div class="pricing-card-items">
			<div class="pricing-header">
				<h3><?php echo $settings['title'];?></h3>
				<p>
					<?php echo $settings['text'];?>
				</p>
			</div>
			<div class="pricing-price">
				<h2><?php echo $settings['subtitle'];?></h2>
			</div>
			<div class="pricing-button <?php echo esc_attr($settings['active_class']);?>">
				<a href="<?php echo esc_url($settings['button_link']['url']);?>" class="theme-btn">
					<?php echo $settings['button'];?>
					<i class="fa-solid fa-arrow-right"></i>
				</a>
			</div>
			<ul class="pricing-list">
				<?php echo $settings['text2'];?>
			</ul>
		</div>

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Pricing());