<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Project_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-project-grid-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Project Grid', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'project_grid',
			[
				'label' => esc_html__( 'Project Grid', 'kanun-core' ),
			]
		);		
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
					'style3'   => esc_html__( 'Style Three', 'kanun-core' ),
					'style4'   => esc_html__( 'Style Four', 'kanun-core' ),
				),
			]
		);

		$this->end_controls_section();

		// Tab Start - 2

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Project Grid Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Hello World', 'kanun-core')],
					],
				'fields' => 
					[	

						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core'),
						],

						'block_subtitle' =>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Subtitle', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core'),
						],	
						
						'block_button_link' =>
						[
						  'name' => 'block_button_link',
						  'label' => __( 'Button Url', 'kanun-core' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],						  
					   ],

						'block_image' => 	
						[
						'name' => 'block_image',
						'label' => __( 'Image', 'kanun-core' ),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text' => 	
						[
						'name' => 'block_alt_text',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core'),
						],

						'block_col_number' =>
						[
							'name' => 'block_col_number',
							'label' => __( 'Select Column', 'kanun-core' ),
							'type' => Controls_Manager::SELECT,
							'options' => [
								'col-xl-12' => __( 'Col XL 12', 'kanun-core' ),
								'col-xl-9' => __( 'Col XL 9', 'kanun-core' ),
								'col-xl-8' => __( 'Col XL 8', 'kanun-core' ),
								'col-xl-7' => __( 'Col XL 7', 'kanun-core' ),
								'col-xl-6' => __( 'Col XL 6', 'kanun-core' ),
								'col-xl-5' => __( 'Col XL 5', 'kanun-core' ),
								'col-xl-4' => __( 'Col XL 4', 'kanun-core' ),
								'col-xl-3' => __( 'Col XL 3', 'kanun-core' ),
								],
								'default' => 'col-xl-12',
						],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($) {

// js code start



// js code end 

  });
</script>';


?>

<?php  if ( 'style1' === $settings['style'] ) : ?>	

	<div class="row">
		<?php foreach($settings['repeat'] as $item):?>	
		<div class="<?php echo esc_attr($item['block_col_number']); ?>">
			<div class="project-card-items img-custom-anim-left wow" data-wow-delay=".3s">
				<div class="project-image">
				<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
					<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
				<?php endif;?>
					<div class="project-content">
						<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
						<h3>
							<a href="<?php echo esc_url($item['block_button_link']['url']);?>">
								<?php echo wp_kses($item['block_title'], $allowed_tags);?>
							</a>
						</h3>
					</div>
				</div>
			</div>
		</div>
		<?php endforeach; ?>
	</div>

<?php  elseif ( 'style2' === $settings['style'] ) : ?>		

  

<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Project_Grid());