<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Service_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-service-grid-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Grid', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'service-grid',
			[
				'label' => esc_html__( 'Service Grid', 'kanun-core' ),
			]
		);		
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
					'style3'   => esc_html__( 'Style Three', 'kanun-core' ),
				),
			]
		);

		$this->add_control('column_grid', [
            'label' => esc_html__('Column Grid', 'kanun-core'),
            'type' => Controls_Manager::SELECT,
            'options' => array(
                'col-lg-2' => esc_html__('col-lg-2', 'kanun-core'),
                'col-lg-3' => esc_html__('col-lg-3', 'kanun-core'),
                'col-lg-4' => esc_html__('col-lg-4', 'kanun-core'),
                'col-lg-6' => esc_html__('col-lg-6', 'kanun-core'),
            ),
            'default' => 'col-lg-4',
            'description' => esc_html__('Select Service Grid', 'kanun-core'),
        ]);

		$this->end_controls_section();

		// Tab Start - 2

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Hello World', 'kanun-core')],
					],
				'fields' => 
					[						

						'block_icons' =>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'kanun-core'),
							'type' => Controls_Manager::ICONS,							
						],

						'block_image' =>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'kanun-core' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text' =>
						[
						'name' => 'block_alt_text',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXT,
						'default' => esc_html__('', 'kanun-core')
						],	

						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_text' =>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],	

						'block_button' =>

						[
							'name' => 'block_button',
							'label'       => __( 'Button', 'kanun-core' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'kanun-core' ),
							'default' => esc_html__('View Details', 'kanun-core'),
						],
						
						'block_button_link' =>
						[
						  'name' => 'block_button_link',
						  'label' => __( 'Link', 'kanun-core' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   ],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($) {

// js code start



// js code end 

  });
</script>';


?>

<?php  if ( 'style1' === $settings['style'] ) : ?>	

	<div class="row">
		<?php foreach($settings['repeat'] as $item):?>	
		<div class="<?php echo esc_attr($settings['column_grid']); ?>">			
			<div class="service-main-items">
				<div class="service-card img-custom-anim-left wow" data-wow-delay=".3s">
					<div class="icon">
						<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i>
					</div>
					<div class="content">
						<h4>
							<a href="<?php echo esc_url($item['block_button_link']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a>
						</h4>
						<p>
							<?php echo wp_kses($item['block_text'], $allowed_tags);?>
						</p>
					</div>
				</div>

				<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
				<div class="service-image img-custom-anim-right wow" data-wow-delay=".5s">			
					<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">			
				</div>
				<?php endif;?>
			</div>
		</div>
		<?php endforeach; ?>
	</div>

<?php  elseif ( 'style2' === $settings['style'] ) : ?>		

	<div class="row">
		<?php foreach($settings['repeat'] as $item):?>	
		<div class="<?php echo esc_attr($settings['column_grid']); ?> col-md-6 wow fadeInUp" data-wow-delay=".3s">
			<div class="service-box-items">
				<div class="service-content">
					<h4>
						<a href="<?php echo esc_url($item['block_button_link']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a>
					</h4>
					<p>
						<?php echo wp_kses($item['block_text'], $allowed_tags);?>
					</p>
					<div class="service-button">
						<div class="icon">
						<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
						<div class="service-image img-custom-anim-right wow" data-wow-delay=".5s">			
							<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">			
						</div>
						<?php endif;?>
						</div>
						<a href="<?php echo esc_url($item['block_button_link']['url']);?>" class="theme-btn">
							<?php echo wp_kses($item['block_button'], $allowed_tags);?>
							<i class="fa-solid fa-arrow-right"></i>
						</a>
					</div>
				</div> 
			</div>
		</div>
		<?php endforeach; ?>
	</div>

	<?php  elseif ( 'style3' === $settings['style'] ) : ?>		

		<div class="service-wrapper m-0 p-0">
			<div class="service-main-box">
				<?php foreach($settings['repeat'] as $item):?>
				<div class="service-items">
					<div class="icon">
						<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i>
					</div>
					<div class="content">
						<h3>
							<a href="<?php echo esc_url($item['block_button_link']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a>
						</h3>
					</div>
					<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
					<div class="service-hover d-none d-md-block bg-cover" style="background-image: url('<?php echo wp_get_attachment_url($item['block_image']['id']);?>');"></div>
					<?php endif;?>
				</div>
				<?php endforeach; ?>
			</div>
		</div>

<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Service_Grid());