<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Team_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-team-grid-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Grid', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'team_grid',
			[
				'label' => esc_html__( 'Team Grid', 'kanun-core' ),
			]
		);		
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
				),
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your sub title', 'kanun-core' ),
			]
		);
	
		$this->add_control(
				'title',
				[
					'label'       => __( 'Title', 'kanun-core' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter your title', 'kanun-core' ),
				]
		);

		$this->add_control(
			'button_link',
			[
			  'label' => __( 'Button Url', 'kanun-core' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);

		$this->end_controls_section();

		// Tab Start - 2

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Team Grid Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Hello World', 'kanun-core')],
					],
				'fields' => 
					[						

						'block_icons' =>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'kanun-core'),
							'type' => Controls_Manager::ICONS,							
						],

						'block_button_link' =>
						[
						  'name' => 'block_button_link',
						  'label' => __( 'Url', 'kanun-core' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   ],

						'block_image' =>

						[
						'name' => 'block_image',
						'label' => __( 'Image', 'kanun-core' ),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text' =>

						[
						'name' => 'block_alt_text',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],	

						'block_subtitle' =>

						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Subtitle', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],	
						  
						'block_title' =>

						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],
						
						'block_text' =>

						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],										   
						
					  
					  'block_button_link1' =>
					   
					  [
						'name' => 'block_button_link1',
						'label' => __( 'Facebook Url', 'kanun-core' ),
						'type' => Controls_Manager::URL,
						'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						'show_external' => true,
						'default' => [
						  'url' => '#',
						  'is_external' => true,
						  'nofollow' => true,
						],
					 ],
			  
					  'block_button_link2' =>
					  
					  [
						'name' => 'block_button_link2',
						'label' => __( 'Twitter Url', 'kanun-core' ),
						'type' => Controls_Manager::URL,
						'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						'show_external' => true,
						'default' => [
						  'url' => '',
						  'is_external' => true,
						  'nofollow' => true,
						],
					 ],
			  
					  'block_button_link3' =>
					  
					  [
						'name' => 'block_button_link3',
						'label' => __( 'Youtube Url', 'kanun-core' ),
						'type' => Controls_Manager::URL,
						'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						'show_external' => true,
						'default' => [
						  'url' => '',
						  'is_external' => true,
						  'nofollow' => true,
						],
					 ],
			  
					  'block_button_link4' =>
					  
					  [
						'name' => 'block_button_link4',
						'label' => __( 'linkedIn Url', 'kanun-core' ),
						'type' => Controls_Manager::URL,
						'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						'show_external' => true,
						'default' => [
						  'url' => '',
						  'is_external' => true,
						  'nofollow' => true,
						],
					 ],
			  
					  'block_button_link5' =>
					  
					  [
						'name' => 'block_button_link5',
						'label' => __( 'Instagram Url', 'kanun-core' ),
						'type' => Controls_Manager::URL,
						'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
						'show_external' => true,
						'default' => [
						  'url' => '',
						  'is_external' => true,
						  'nofollow' => true,
						],
					 ],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>


<?php
	  echo '
	 <script>
 jQuery(document).ready(function($) {

// js code start

	if($(".team-slider").length > 0) {
	const teamSlider = new Swiper(".team-slider", {
		spaceBetween: 30,
		speed: 1300,
		loop: true,
		autoplay: {
			delay: 2000,
			disableOnInteraction: false,
		},
		navigation: {
			prevEl: ".array-prev",
			nextEl: ".array-next",
		},
		breakpoints: {
			1199: {
				slidesPerView: 4,
			},
			991: {
				slidesPerView: 4,
			},
			767: {
				slidesPerView: 3,
			},
			575: {
				slidesPerView: 2,
			},
			0: {
				slidesPerView: 1,
			},
		},
	});
}

// js code end 

  });
</script>';


?>


<?php  if ( 'style1' === $settings['style'] ) : ?>	

	<div class="team-card-items">
		<div class="team-image">
			<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
				<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
			<?php endif;?>
			<div class="team-social">
				<?php foreach($settings['repeat'] as $item):?>	
					<a href="<?php echo esc_url($item['block_button_link']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a>
				<?php endforeach; ?>
				</div>
		</div>
		<div class="team-content">

			<h4>
				<a href="<?php echo esc_url($settings['button_link']['url']);?>">
					<?php echo $settings['title'];?>
				</a>
			</h4>

			<p><?php echo $settings['subtitle'];?></p>
		</div>
	</div>

<?php  elseif ( 'style2' === $settings['style'] ) : ?>		

	<div class="swiper team-slider">
		<div class="swiper-wrapper">
			<?php foreach($settings['repeat'] as $item):?>	
			<div class="swiper-slide">
				<div class="team-main-item">
					<div class="team-card-item2">
						<div class="team-image">
						<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
							<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
						<?php endif;?>
						</div>
					</div>
					<div class="team-content-hover">
						<h4>
							<a href="<?php echo esc_url($item['block_button_link']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a>
						</h4>
						<span>
							<?php echo wp_kses($item['block_subtitle'], $allowed_tags);?>
						</span>
						<p>
							<?php echo wp_kses($item['block_text'], $allowed_tags);?>
						</p>
						<div class="team-social">
						<?php if (!empty($item['block_button_link1']['url'])) : ?>
							<a href="<?php echo esc_url($item['block_button_link1']['url']);?>"><i class="fab fa-facebook-f"></i></a>
						<?php endif; ?> 
						<?php if (!empty($item['block_button_link2']['url'])) : ?>
							<a href="<?php echo esc_url($item['block_button_link2']['url']);?>"><i class="fab fa-twitter"></i></a>
						<?php endif; ?> 
						<?php if (!empty($item['block_button_link3']['url'])) : ?>
							<a href="<?php echo esc_url($item['block_button_link3']['url']);?>"><i class="fab fa-youtube"></i></a>
						<?php endif; ?> 
						<?php if (!empty($item['block_button_link4']['url'])) : ?>
							<a href="<?php echo esc_url($item['block_button_link4']['url']);?>"><i class="fab fa-linkedin-in"></i></a>
						<?php endif; ?> 
						<?php if (!empty($item['block_button_link5']['url'])) : ?>
							<a href="<?php echo esc_url($item['block_button_link5']['url']);?>"><i class="fab fa-instagram"></i></a>
						<?php endif; ?> 
						</div>
					</div>
				</div>
			</div>
			<?php endforeach; ?>
		</div>
	</div>

<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Team_Grid());