<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Testimonials extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-testimonials-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials Widget', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'testimonials',
			[
				'label' => esc_html__( 'Testimonials', 'kanun-core' ),
			]
		);		
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
					'style3'   => esc_html__( 'Style Three', 'kanun-core' ),
				),
			]
		);
	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
				'condition'	=> ['style' => ['style1']],
			]
		);

		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1']],
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				  'condition'	=> ['style' => ['style1']],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1']],
			]
		);

		$this->add_control(
			'image2',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				  'condition'	=> ['style' => ['style1']],
				]
		);	
		
		$this->add_control(
			'alt_text2',
			[
				'label'       => __( 'Alt text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1']],
			]
		);

		$this->end_controls_section();

		// Tab Start - 2

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'kanun-core')],
					],
				'fields' => 
					[						
					
						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_subtitle' =>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Subtitle', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_subtitle2' =>
						[
							'name' => 'block_subtitle2',
							'label' => esc_html__('Subtitle 2', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_text' =>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_image' =>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'kanun-core' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text' =>
						[
						'name' => 'block_alt_text',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],	

						
						'block_image2' =>
						[
							'name' => 'block_image2',
							'label' => __( 'Image', 'kanun-core' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text2' =>
						[
						'name' => 'block_alt_text2',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],	

						
						'block_image3' =>
						[
							'name' => 'block_image3',
							'label' => __( 'Image', 'kanun-core' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text3' =>
						[
						'name' => 'block_alt_text3',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],	

						'block_rating' =>
						[
							'name' => 'block_rating',
							'label'   => esc_html__( 'Select Rating', 'kanun-core' ),
							'type'    => Controls_Manager::SELECT,
							'default' => 'rat1',
							'options' => array(
								'rat1'   => esc_html__( 'Rating One', 'kanun-core' ),
								'rat2'   => esc_html__( 'Rating Two', 'kanun-core' ),
								'rat3'   => esc_html__( 'Rating Three', 'kanun-core' ),
								'rat4'   => esc_html__( 'Rating Four', 'kanun-core' ),
								'rat5'   => esc_html__( 'Rating Five', 'kanun-core' ),
							),
						],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($) {

// js code start

if($(".testimonial-slider").length > 0) {
	const testimonialSlider = new Swiper(".testimonial-slider", {
		spaceBetween: 30,
		speed: 2000,
		loop: true,
		autoplay: {
			delay: 2000,
			disableOnInteraction: false,
		},
		navigation: {
			prevEl: ".array-prev",
			nextEl: ".array-next",
		},
		breakpoints: {
			1199: {
				slidesPerView: 2,
			},
			991: {
				slidesPerView: 2,
			},
			767: {
				slidesPerView: 1,
			},
			575: {
				slidesPerView: 1,
			},
			0: {
				slidesPerView: 1,
			},
		},
	});
}


if($(".testimonial-slider2").length > 0) {
	const testimonialSlider2 = new Swiper(".testimonial-slider2", {
		spaceBetween: 30,
		speed: 2000,
		loop: true,
		autoplay: {
			delay: 2000,
			disableOnInteraction: false,
		},
		breakpoints: {
			1199: {
				slidesPerView: 3,
			},
			991: {
				slidesPerView: 2,
			},
			767: {
				slidesPerView: 1,
			},
			575: {
				slidesPerView: 1,
			},
			0: {
				slidesPerView: 1,
			},
		},
	});
}

// js code end 

  });
</script>';


?>

<?php  if ( 'style1' === $settings['style'] ) : ?>	


	<div class="testimonial-wrapper">
		<div class="row g-4">
			<div class="col-xl-4">
				<div class="testimonial-card img-custom-anim-left wow" data-wow-delay=".3s">
					<div class="testimonial-image">
					<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
						<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
					<?php endif;?>
						<div class="group-image">
						<?php  if ( !empty(esc_url($settings['image2']['id']) )) : ?>   
							<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
						<?php endif;?>
						</div>
					</div>
					<?php if($settings['title']): ?>
					<div class="testimonial-content">
						<h3><?php echo $settings['title'];?></h3>
						<div class="star">
							<?php echo $settings['text'];?>
						</div>
					</div>
					<?php endif;?>
				</div>
			</div>
			<div class="col-xl-8">
				<div class="swiper testimonial-slider">
					<div class="swiper-wrapper">
						<?php foreach($settings['repeat'] as $item):?>	
						<div class="swiper-slide">
							<div class="Testimonial-box-items">
								<svg xmlns="http://www.w3.org/2000/svg" width="82" height="52" viewBox="0 0 82 52" fill="none">
									<path d="M80.1149 0C80.9533 0 81.7067 0.551388 81.9335 1.36927C82.185 2.27872 81.7041 3.23087 80.8142 3.58094C74.9044 5.90961 70.5645 9.90136 67.8864 15.4646C76.0825 17.5539 81.9997 24.8937 81.9997 33.4286C81.9997 43.6692 73.5399 52 63.1416 52C52.7434 52 44.2845 43.6692 44.2845 33.4286C44.2689 33.288 42.6042 5.59947 79.8291 0.0208015C79.9251 0.00631714 80.02 0 80.1149 0ZM63.1416 48.2857C71.4596 48.2857 78.2261 41.6206 78.2261 33.4286C78.2261 25.9474 72.5429 19.6142 65.0072 18.6985C64.4324 18.6277 63.9219 18.3021 63.6235 17.8143C63.3241 17.3264 63.2688 16.7306 63.4742 16.1974C64.9878 12.261 67.1418 8.91949 69.9165 6.19264C46.9045 14.1145 48.0368 33.074 48.0524 33.2908C48.0581 41.6206 54.8246 48.2857 63.1416 48.2857Z" fill="#B68C5A"/>
									<path d="M35.8415 0C36.6798 0 37.4333 0.551388 37.6601 1.36927C37.9115 2.27872 37.4307 3.23087 36.5408 3.58094C30.6309 5.90961 26.291 9.90136 23.613 15.4646C31.8091 17.5539 37.7263 24.8937 37.7263 33.4286C37.7263 43.6692 29.2664 52 18.8682 52C8.46999 52 0.0110893 43.6692 0.0110893 33.4286C-0.00457001 33.288 -1.66922 5.59947 35.5557 0.0208015C35.6517 0.00631714 35.7466 0 35.8415 0ZM18.8682 48.2857C27.1862 48.2857 33.9527 41.6206 33.9527 33.4286C33.9527 25.9474 28.2694 19.6142 20.7338 18.6985C20.159 18.6277 19.6485 18.3021 19.35 17.8143C19.0506 17.3264 18.9954 16.7306 19.2008 16.1974C20.7143 12.261 22.8684 8.91949 25.643 6.19264C2.63107 14.1145 3.76335 33.074 3.77901 33.2908C3.78467 41.6206 10.5512 48.2857 18.8682 48.2857Z" fill="#B68C5A"/>
									</svg>
								<p>
									<?php echo wp_kses($item['block_text'], $allowed_tags);?>
								</p>
								<div class="client-info-items">
									<div class="client-info">
										<div class="client-img">
										<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php endif;?>
										</div>
										<div class="client-content">
											<h4>
											<?php echo wp_kses($item['block_title'], $allowed_tags);?>
											</h4>
											<span>
											<?php echo wp_kses($item['block_subtitle'], $allowed_tags);?>
											</span>
										</div>
									</div>
									<div class="star">
										<?php if ( 'rat1' === $item['block_rating'] ) : ?>
											<i class="fas fa-star"></i>
											<i class="far fa-star"></i>
											<i class="far fa-star"></i>
											<i class="far fa-star"></i>
											<i class="far fa-star"></i>
										<?php elseif ( 'rat2' === $item['block_rating'] ) : ?>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="far fa-star"></i>
											<i class="far fa-star"></i>
											<i class="far fa-star"></i>
										<?php elseif ( 'rat3' === $item['block_rating'] ) : ?>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="far fa-star"></i>
											<i class="far fa-star"></i>
										<?php elseif ( 'rat4' === $item['block_rating'] ) : ?>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="far fa-star"></i>
										<?php elseif ( 'rat5' === $item['block_rating'] ) : ?>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
											<i class="fas fa-star"></i>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
						<?php endforeach; ?>
					</div>
				</div>
			</div>
		</div>
	</div>

	<?php  elseif ( 'style2' === $settings['style'] ) : ?>	

		<div class="swiper testimonial-slider2">
			<div class="swiper-wrapper">
				<?php foreach($settings['repeat'] as $item):?>	
				<div class="swiper-slide">
					<div class="testimonial-main-item">
						<div class="top-shape">
						<?php if(!empty(wp_get_attachment_url($item['block_image2']['id']))): ?>
							<img src="<?php echo wp_get_attachment_url($item['block_image2']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text2'], $allowed_tags);?>">
						<?php endif;?>
						</div>
						<div class="testimonial-card-item2">
							<div class="polygon-shape">
							<?php if(!empty(wp_get_attachment_url($item['block_image3']['id']))): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image3']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text3'], $allowed_tags);?>">
							<?php endif;?>
							</div>
							<div class="testimonial-content">
								<div class="star">
								<?php if ( 'rat1' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat2' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat3' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat4' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat5' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
								<?php endif; ?>
								</div>
								<p>
									<?php echo wp_kses($item['block_text'], $allowed_tags);?>
								</p>
								<div class="info-item">
									<div class="content">
										<h4><?php echo wp_kses($item['block_subtitle2'], $allowed_tags);?></h4>
									</div>
									<div class="icon">
										<svg xmlns="http://www.w3.org/2000/svg" width="50" height="50" viewBox="0 0 50 50" fill="none">
											<circle cx="25" cy="25" r="25" fill="#B68C5A"/>
											<path d="M38.7322 16C39.0224 16 39.2833 16.1909 39.3617 16.474C39.4488 16.7888 39.2823 17.1184 38.9743 17.2396C36.9286 18.0456 35.4263 19.4274 34.4993 21.3531C37.3364 22.0764 39.3847 24.6171 39.3847 27.5714C39.3847 31.1163 36.4563 34 32.8569 34C29.2575 34 26.3294 31.1163 26.3294 27.5714C26.324 27.5228 25.7478 17.9383 38.6333 16.0072C38.6665 16.0022 38.6994 16 38.7322 16ZM32.8569 32.7143C35.7362 32.7143 38.0784 30.4071 38.0784 27.5714C38.0784 24.9818 36.1111 22.7895 33.5026 22.4725C33.3037 22.448 33.127 22.3354 33.0237 22.1665C32.92 21.9976 32.9009 21.7914 32.972 21.6068C33.4959 20.2442 34.2415 19.0875 35.202 18.1436C27.2363 20.8858 27.6283 27.4487 27.6337 27.5237C27.6356 30.4071 29.9779 32.7143 32.8569 32.7143Z" fill="white"/>
											<path d="M23.408 16C23.6982 16 23.959 16.1909 24.0375 16.474C24.1246 16.7888 23.9581 17.1184 23.6501 17.2396C21.6044 18.0456 20.1021 19.4274 19.1751 21.3531C22.0122 22.0764 24.0604 24.6171 24.0604 27.5714C24.0604 31.1163 21.132 34 17.5327 34C13.9333 34 11.0052 31.1163 11.0052 27.5714C10.9998 27.5228 10.4235 17.9383 23.3091 16.0072C23.3423 16.0022 23.3752 16 23.408 16ZM17.5327 32.7143C20.412 32.7143 22.7542 30.4071 22.7542 27.5714C22.7542 24.9818 20.7869 22.7895 18.1784 22.4725C17.9795 22.448 17.8027 22.3354 17.6994 22.1665C17.5958 21.9976 17.5767 21.7914 17.6478 21.6068C18.1717 20.2442 18.9173 19.0875 19.8778 18.1436C11.9121 20.8858 12.304 27.4487 12.3095 27.5237C12.3114 30.4071 14.6537 32.7143 17.5327 32.7143Z" fill="white"/>
										</svg>
									</div>
								</div>
							</div>
						</div>
						<div class="client-info-item">
							<div class="client-image">
							<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
							<?php endif;?>
							</div>
							<div class="info-text">
								<h4>
									<?php echo wp_kses($item['block_title'], $allowed_tags);?>
								</h4>
								<span>
									<?php echo wp_kses($item['block_subtitle'], $allowed_tags);?>
								</span>
							</div>
						</div>
					</div>
				</div>
				<?php endforeach; ?>
			</div>
		</div>

		<?php  elseif ( 'style3' === $settings['style'] ) : ?>	

			<div class="row">
				<?php foreach($settings['repeat'] as $item):?>	
				<div class="col-xl-4 col-lg-6 col-md-6">
				<div class="testimonial-main-item">
						<div class="top-shape">
						<?php if(!empty(wp_get_attachment_url($item['block_image2']['id']))): ?>
							<img src="<?php echo wp_get_attachment_url($item['block_image2']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text2'], $allowed_tags);?>">
						<?php endif;?>
						</div>
						<div class="testimonial-card-item2">
							<div class="polygon-shape">
							<?php if(!empty(wp_get_attachment_url($item['block_image3']['id']))): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image3']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text3'], $allowed_tags);?>">
							<?php endif;?>
							</div>
							<div class="testimonial-content">
								<div class="star">
								<?php if ( 'rat1' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat2' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat3' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat4' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="far fa-star"></i>
								<?php elseif ( 'rat5' === $item['block_rating'] ) : ?>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
									<i class="fas fa-star"></i>
								<?php endif; ?>
								</div>
								<p>
									<?php echo wp_kses($item['block_text'], $allowed_tags);?>
								</p>
								<div class="info-item">
									<div class="content">
										<h4><?php echo wp_kses($item['block_subtitle2'], $allowed_tags);?></h4>
									</div>
									<div class="icon">
										<svg xmlns="http://www.w3.org/2000/svg" width="50" height="50" viewBox="0 0 50 50" fill="none">
											<circle cx="25" cy="25" r="25" fill="#B68C5A"/>
											<path d="M38.7322 16C39.0224 16 39.2833 16.1909 39.3617 16.474C39.4488 16.7888 39.2823 17.1184 38.9743 17.2396C36.9286 18.0456 35.4263 19.4274 34.4993 21.3531C37.3364 22.0764 39.3847 24.6171 39.3847 27.5714C39.3847 31.1163 36.4563 34 32.8569 34C29.2575 34 26.3294 31.1163 26.3294 27.5714C26.324 27.5228 25.7478 17.9383 38.6333 16.0072C38.6665 16.0022 38.6994 16 38.7322 16ZM32.8569 32.7143C35.7362 32.7143 38.0784 30.4071 38.0784 27.5714C38.0784 24.9818 36.1111 22.7895 33.5026 22.4725C33.3037 22.448 33.127 22.3354 33.0237 22.1665C32.92 21.9976 32.9009 21.7914 32.972 21.6068C33.4959 20.2442 34.2415 19.0875 35.202 18.1436C27.2363 20.8858 27.6283 27.4487 27.6337 27.5237C27.6356 30.4071 29.9779 32.7143 32.8569 32.7143Z" fill="white"/>
											<path d="M23.408 16C23.6982 16 23.959 16.1909 24.0375 16.474C24.1246 16.7888 23.9581 17.1184 23.6501 17.2396C21.6044 18.0456 20.1021 19.4274 19.1751 21.3531C22.0122 22.0764 24.0604 24.6171 24.0604 27.5714C24.0604 31.1163 21.132 34 17.5327 34C13.9333 34 11.0052 31.1163 11.0052 27.5714C10.9998 27.5228 10.4235 17.9383 23.3091 16.0072C23.3423 16.0022 23.3752 16 23.408 16ZM17.5327 32.7143C20.412 32.7143 22.7542 30.4071 22.7542 27.5714C22.7542 24.9818 20.7869 22.7895 18.1784 22.4725C17.9795 22.448 17.8027 22.3354 17.6994 22.1665C17.5958 21.9976 17.5767 21.7914 17.6478 21.6068C18.1717 20.2442 18.9173 19.0875 19.8778 18.1436C11.9121 20.8858 12.304 27.4487 12.3095 27.5237C12.3114 30.4071 14.6537 32.7143 17.5327 32.7143Z" fill="white"/>
										</svg>
									</div>
								</div>
							</div>
						</div>
						<div class="client-info-item">
							<div class="client-image">
							<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
							<?php endif;?>
							</div>
							<div class="info-text">
								<h4>
									<?php echo wp_kses($item['block_title'], $allowed_tags);?>
								</h4>
								<span>
									<?php echo wp_kses($item['block_subtitle'], $allowed_tags);?>
								</span>
							</div>
						</div>
					</div>
				</div>
				<?php endforeach; ?>
			</div>

<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Testimonials());