<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Testimonials_With_Brand extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-testimonials-with-brand-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials With Brand', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'testimonials-with-brand',
			[
				'label' => esc_html__( 'Testimonials With Brand', 'kanun-core' ),
			]
		);	
		
		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__('Background image', 'kanun-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);		
	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);

		$this->end_controls_section();

		// Tab Start - 2

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'kanun-core')],
					],
				'fields' => 
					[				
						
						'block_text' =>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_subtitle' =>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Subtitle', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_image' =>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'kanun-core' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_rating' =>
						[
							'name' => 'block_rating',
							'label'   => esc_html__( 'Select Rating', 'kanun-core' ),
							'type'    => Controls_Manager::SELECT,
							'default' => 'rat1',
							'options' => array(
								'rat1'   => esc_html__( 'Rating One', 'kanun-core' ),
								'rat2'   => esc_html__( 'Rating Two', 'kanun-core' ),
								'rat3'   => esc_html__( 'Rating Three', 'kanun-core' ),
								'rat4'   => esc_html__( 'Rating Four', 'kanun-core' ),
								'rat5'   => esc_html__( 'Rating Five', 'kanun-core' ),
							),
						],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');

		$image_id = !empty($settings['image']['id']) ? esc_url($settings['image']['id']) : '';
		$content_col_class = $image_id ? 'col-lg-9' : 'col-lg-12';

		?>

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($) {

// js code start

	if($(".testimonial-slider3").length > 0) {
		const testimonialSlider3 = new Swiper(".testimonial-slider3", {
			spaceBetween: 30,
			speed: 2000,
			loop: true,
			autoplay: {
				delay: 2000,
				disableOnInteraction: false,
			},
			navigation: {
				prevEl: ".array-prev",
				nextEl: ".array-next",
			},
			breakpoints: {
				1199: {
					slidesPerView: 1,
				},
				991: {
					slidesPerView: 1,
				},
				767: {
					slidesPerView: 1,
				},
				575: {
					slidesPerView: 1,
				},
				0: {
					slidesPerView: 1,
				},
			},
		});
	}

	if($(".brand-slider").length > 0) {
		const brandSlider = new Swiper(".brand-slider", {
			spaceBetween: 30,
			speed: 1300,
			loop: true,
			centeredSlides: true,
			autoplay: {
				delay: 2000,
				disableOnInteraction: false,
			},

			breakpoints: {
				1199: {
					slidesPerView: 6,
				},
				991: {
					slidesPerView: 5,
				},
				767: {
					slidesPerView: 4,
				},
				575: {
					slidesPerView: 3,
				},
				0: {
					slidesPerView: 1,
				},
			},
		});
	}

// js code end 

  });
</script>';


?>


	<section class="testimonial-section3 section-padding fix bg-cover" style="background-image: url(<?php echo wp_get_attachment_url($settings['bg_image']['id']);?>);">
		<div class="container">
			<div class="row g-4">
				<div class="col-xl-3">
					<div class="array-button wow fadeInUp" data-wow-delay=".3s">
						<button class="array-prev">
							<i class="fa-solid fa-arrow-left"></i>
						</button>
						<button class="array-next">
							<i class="fa-solid fa-arrow-right"></i>
						</button>
					</div>
				</div>
				<div class="col-xl-9">
					<div class="section-title wow fadeInUp" data-wow-delay=".5s">
						<h2 class="text-white">
							<?php echo $settings['title'];?>
						</h2>
					</div>
				</div>
			</div>
		</div>
		<div class="testimonial-main-ber">
			<div class="container">
				<div class="row g-4">
					<?php  if ($image_id) : ?>  
					<div class="col-lg-3">
						<div class="client-image">
							<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt=""/>							
						</div>
					</div>
					<?php endif;?>
					<div class="<?php echo $content_col_class; ?>">
						<div class="swiper testimonial-slider3">
							<div class="swiper-wrapper">
								<?php foreach($settings['repeat'] as $item):?>	
								<div class="swiper-slide">
									<div class="testimonial-card-items">
										<div class="icon">
											<svg xmlns="http://www.w3.org/2000/svg" width="82" height="52" viewBox="0 0 82 52" fill="none">
												<path d="M80.1169 0C80.9552 0 81.7087 0.551388 81.9355 1.36927C82.1869 2.27872 81.7061 3.23087 80.8162 3.58094C74.9063 5.90961 70.5664 9.90136 67.8884 15.4646C76.0845 17.5539 82.0017 24.8937 82.0017 33.4286C82.0017 43.6692 73.5418 52 63.1436 52C52.7454 52 44.2865 43.6692 44.2865 33.4286C44.2708 33.288 42.6062 5.59947 79.8311 0.0208015C79.9271 0.00631714 80.022 0 80.1169 0ZM63.1436 48.2857C71.4616 48.2857 78.2281 41.6206 78.2281 33.4286C78.2281 25.9474 72.5448 19.6142 65.0092 18.6985C64.4343 18.6277 63.9239 18.3021 63.6254 17.8143C63.326 17.3264 63.2708 16.7306 63.4762 16.1974C64.9897 12.261 67.1437 8.91949 69.9184 6.19264C46.9065 14.1145 48.0387 33.074 48.0544 33.2908C48.0601 41.6206 54.8266 48.2857 63.1436 48.2857Z" fill="#B68C5A"/>
												<path d="M35.8434 0C36.6818 0 37.4353 0.551388 37.662 1.36927C37.9135 2.27872 37.4326 3.23087 36.5428 3.58094C30.6329 5.90961 26.293 9.90136 23.6149 15.4646C31.811 17.5539 37.7282 24.8937 37.7282 33.4286C37.7282 43.6692 29.2684 52 18.8702 52C8.47194 52 0.0130424 43.6692 0.0130424 33.4286C-0.00261688 33.288 -1.66727 5.59947 35.5576 0.0208015C35.6536 0.00631714 35.7485 0 35.8434 0ZM18.8702 48.2857C27.1881 48.2857 33.9547 41.6206 33.9547 33.4286C33.9547 25.9474 28.2714 19.6142 20.7357 18.6985C20.1609 18.6277 19.6504 18.3021 19.352 17.8143C19.0526 17.3264 18.9973 16.7306 19.2028 16.1974C20.7163 12.261 22.8703 8.91949 25.645 6.19264C2.63302 14.1145 3.7653 33.074 3.78096 33.2908C3.78662 41.6206 10.5531 48.2857 18.8702 48.2857Z" fill="#B68C5A"/>
												</svg>
										</div>
										<div class="content">
											<p>
												<?php echo wp_kses($item['block_text'], $allowed_tags);?>
											</p>
											<div class="info-text">
												<div class="text">
													<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
													<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
												</div>
												<div class="star">
												<?php if ( 'rat1' === $item['block_rating'] ) : ?>
													<i class="fas fa-star"></i>
													<i class="far fa-star"></i>
													<i class="far fa-star"></i>
													<i class="far fa-star"></i>
													<i class="far fa-star"></i>
												<?php elseif ( 'rat2' === $item['block_rating'] ) : ?>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="far fa-star"></i>
													<i class="far fa-star"></i>
													<i class="far fa-star"></i>
												<?php elseif ( 'rat3' === $item['block_rating'] ) : ?>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="far fa-star"></i>
													<i class="far fa-star"></i>
												<?php elseif ( 'rat4' === $item['block_rating'] ) : ?>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="far fa-star"></i>
												<?php elseif ( 'rat5' === $item['block_rating'] ) : ?>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
													<i class="fas fa-star"></i>
												<?php endif; ?>
												</div>
											</div>
										</div>
									</div>
								</div>
								<?php endforeach; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="brand-section section-padding pb-0">
			<div class="container">
				<div class="brand-wrapper">
					<div class="swiper brand-slider">
						<div class="swiper-wrapper">
							<?php foreach($settings['repeat'] as $item):?>
							<div class="swiper-slide">
								<div class="brand-image text-center">
									<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="">
									<?php endif;?>
								</div>
							</div>
							<?php endforeach; ?>
						</div>
						</div>
				</div>
			</div>
		</div>
	</section>

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Testimonials_With_Brand());