<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Theme_Image_Box extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-theme-image-box-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Theme Image Box', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'theme_image_box',
			[
				'label' => esc_html__( 'Theme Image Box', 'kanun-core' ),
			]
		);	
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
					'style3'   => esc_html__( 'Style Three', 'kanun-core' ),
				),
			]
		);
		
		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				  'condition'	=> ['style' => ['style1','style2','style3']],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1','style2','style3']],
			]
		);

		$this->add_control(
			'video_link',
			[
			  'label' => __( 'Video Url', 'kanun-core' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
			  'show_external' => true,
			  'default' => [
				'url' => 'https://www.youtube.com/watch?v=Cn4G2lZ_g2I',
				'is_external' => true,
				'nofollow' => true,
			  ],
			  'condition'	=> ['style' => ['style2']],			
		   ]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your sub title', 'kanun-core' ),
				'condition'	=> ['style' => ['style3']],	
			]
		);
	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'kanun-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'kanun-core' ),
				'condition'	=> ['style' => ['style3']],	
			]
		);

		$this->add_control(
			'button_link',
			[
				'label' => __( 'Button Url', 'kanun-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'kanun-core' ),
				'show_external' => true,
				'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
				],
				'condition'	=> ['style' => ['style3']],	
			
			]
		);

		$this->end_controls_section();

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

	
<?php  if ( 'style1' === $settings['style'] ) : ?>

	<div class="about-wrapper">
		<div class="about-image">
			<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
				<img class="wow img-custom-anim-top" data-wow-duration="1.3s" data-wow-delay="0.3s" src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
			<?php endif;?>
		</div>
	</div>

<?php  elseif ( 'style2' === $settings['style'] ) : ?>

    <div class="faq-wrapper">
		<div class="faq-image">
				<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
					<img class="wow img-custom-anim-right" data-wow-duration="1.3s" data-wow-delay="0.3s" src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
				<?php endif;?>
				<a href="<?php echo esc_url($settings['video_link']['url']);?>"  class="video-btn ripple video-popup">
				<i class="fa-duotone fa-play"></i>
			</a>
		</div>
	</div>

	<?php  elseif ( 'style3' === $settings['style'] ) : ?>

		<div class="about-wrapper-2">
			<div class="about-image">
					<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
						<img class="wow img-custom-anim-left" data-wow-duration="1.3s" data-wow-delay="0.3s" src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
					<?php endif;?>
					<div class="about-box">
						<span>
							<?php echo $settings['subtitle'];?>
						</span>
						<h4>
							<a href="<?php echo esc_url($settings['button_link']['url']);?>"><?php echo $settings['title'];?></a>
						</h4>
					</div>
				</div>
			</div>

<?php endif ;?>	

             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Theme_Image_Box());