<?php
namespace Elementor;

/**
 * Elementor Widget
 * @package Kanun
 * @since 1.0.0
 */ 
 
class Work_Process extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kanun-work-process-widget';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Work Process', 'kanun-core' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flash';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories()
    {
        return ['kanun_widgets'];
    }
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		// Tab Start - 1

		$this->start_controls_section(
			'work_process',
			[
				'label' => esc_html__( 'Work Process', 'kanun-core' ),
			]
		);	
				
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'kanun-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'kanun-core' ),
					'style2'   => esc_html__( 'Style Two', 'kanun-core' ),
				),
			]
		);	
		
		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'kanun-core' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				  'condition'	=> ['style' => ['style1']],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'kanun-core' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Your Text', 'kanun-core' ),
				'condition'	=> ['style' => ['style1']],
			]
		);

		$this->end_controls_section();

		// Tab Start - 2

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Block', 'kanun-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'separator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Hello World', 'kanun-core')],
					],
				'fields' => 
					[	

						'block_subtitle' =>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Sub-Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_text' =>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'kanun-core'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'kanun-core')
						],

						'block_image' =>
						[
						'name' => 'block_image',
						'label' => __( 'Image', 'kanun-core' ),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text' =>
						[
						'name' => 'block_alt_text',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],	

						'block_image2' =>
						[
						'name' => 'block_image2',
						'label' => __( 'Image', 'kanun-core' ),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text2' =>
						[
						'name' => 'block_alt_text2',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],

						'block_image3' =>
						[
						'name' => 'block_image3',
						'label' => __( 'Image', 'kanun-core' ),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
						],	

						'block_alt_text3' =>
						[
						'name' => 'block_alt_text3',
						'label' => esc_html__('Image Text', 'kanun-core'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'kanun-core')
						],
						
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
		
	$this->end_controls_section();	

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>


<?php  if ( 'style1' === $settings['style'] ) : ?>	

	<div class="process-wrapper">
		<div class="process-content ms-0">
			<div class="process-ber">
				<div class="line-shape">
				<?php  if ( !empty(esc_url($settings['image']['id']) )) : ?>   
					<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
				<?php endif;?>
				</div>
				<?php foreach($settings['repeat'] as $item):?>	
				<div class="process-items wow fadeInUp" data-wow-delay=".2s">
					<h6 class="number">
						<?php echo wp_kses($item['block_subtitle'], $allowed_tags);?>
					</h6>
					<div class="content">
						<h3>
							<?php echo wp_kses($item['block_title'], $allowed_tags);?>
						</h3>
						<p>
							<?php echo wp_kses($item['block_text'], $allowed_tags);?>
						</p>
					</div>
				</div>
				<?php endforeach; ?>
			</div>
		</div>
	</div>

	<?php  elseif ( 'style2' === $settings['style'] ) : ?>	

		<div class="row">
			<?php foreach($settings['repeat'] as $item):?>	
			<div class="col-xl-4 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
				<div class="feature-main-area">
					<?php if(!empty(wp_get_attachment_url($item['block_image']['id']))): ?>
					<div class="shape1">					
						<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">					
					</div>
					<?php endif;?>
					<?php if(!empty(wp_get_attachment_url($item['block_image2']['id']))): ?>
					<div class="shape2">						
							<img src="<?php echo wp_get_attachment_url($item['block_image2']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text2'], $allowed_tags);?>">					
					</div>
					<?php endif;?>
					<div class="feature-card-item2">
						<div class="feature-image">
						<?php if(!empty(wp_get_attachment_url($item['block_image3']['id']))): ?>
							<img src="<?php echo wp_get_attachment_url($item['block_image3']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text3'], $allowed_tags);?>">
						<?php endif;?>
							<h6 class="number"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></h6>
						</div>
						<div class="feature-content">
							<h4>
								<?php echo wp_kses($item['block_title'], $allowed_tags);?>
							</h4>
							<p>
								<?php echo wp_kses($item['block_text'], $allowed_tags);?>
							</p>
						</div>
					</div>
				</div>
			</div>
			<?php endforeach; ?>
		</div>

		<?php endif ;?>	
             
		<?php 
	}


}

Plugin::instance()->widgets_manager->register_widget_type(new Work_Process());